@@ -1,27 +1,27 @@
 /***
-* Copyright (C) Microsoft. All rights reserved.
-* Licensed under the MIT license. See LICENSE.txt file in the project root for full license information.
-*
-* =+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+
-*
-* HTTP Library: HTTP listener (server-side) APIs
-*
-* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
-****/
+ * Copyright (C) Microsoft. All rights reserved.
+ * Licensed under the MIT license. See LICENSE.txt file in the project root for full license information.
+ *
+ * =+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+
+ *
+ * HTTP Library: HTTP listener (server-side) APIs
+ *
+ * =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
+ ****/
 #pragma once
 
 #ifndef CASA_HTTP_LISTENER_H
 #define CASA_HTTP_LISTENER_H
 
-#include <limits>
-#include <functional>
-
 #include "cpprest/http_msg.h"
+#include <functional>
+#include <limits>
 #if !defined(_WIN32) && !defined(__cplusplus_winrt) || defined(CPPREST_FORCE_HTTP_LISTENER_ASIO)
 #include <boost/asio/ssl.hpp>
 #endif
 
-#if !defined(_WIN32) || (_WIN32_WINNT >= _WIN32_WINNT_VISTA && !defined(__cplusplus_winrt)) || defined(CPPREST_FORCE_HTTP_LISTENER_ASIO)
+#if !defined(_WIN32) || (_WIN32_WINNT >= _WIN32_WINNT_VISTA && !defined(__cplusplus_winrt)) ||                         \
+    defined(CPPREST_FORCE_HTTP_LISTENER_ASIO)
 
 namespace web
 {
@@ -33,53 +33,50 @@ namespace experimental
 /// HTTP server side library.
 namespace listener
 {
-
 /// <summary>
 /// Configuration class used to set various options when constructing and http_listener instance.
 /// </summary>
 class http_listener_config
 {
 public:
-
     /// <summary>
     /// Create an http_listener configuration with default options.
     /// </summary>
-    http_listener_config()
-        : m_timeout(utility::seconds(120))
-        , m_backlog(0)
-    {}
+    http_listener_config() : m_timeout(utility::seconds(120)), m_backlog(0) {}
 
     /// <summary>
     /// Copy constructor.
     /// </summary>
     /// <param name="other">http_listener_config to copy.</param>
-    http_listener_config(const http_listener_config &other)
+    http_listener_config(const http_listener_config& other)
         : m_timeout(other.m_timeout)
         , m_backlog(other.m_backlog)
 #if !defined(_WIN32) || defined(CPPREST_FORCE_HTTP_LISTENER_ASIO)
         , m_ssl_context_callback(other.m_ssl_context_callback)
 #endif
-    {}
+    {
+    }
 
     /// <summary>
     /// Move constructor.
     /// <summary>
     /// <param name="other">http_listener_config to move from.</param>
-    http_listener_config(http_listener_config &&other)
+    http_listener_config(http_listener_config&& other)
         : m_timeout(std::move(other.m_timeout))
         , m_backlog(std::move(other.m_backlog))
 #if !defined(_WIN32) || defined(CPPREST_FORCE_HTTP_LISTENER_ASIO)
         , m_ssl_context_callback(std::move(other.m_ssl_context_callback))
 #endif
-    {}
+    {
+    }
 
     /// <summary>
     /// Assignment operator.
     /// </summary>
     /// <returns>http_listener_config instance.</returns>
-    http_listener_config & operator=(const http_listener_config &rhs)
+    http_listener_config& operator=(const http_listener_config& rhs)
     {
-        if(this != &rhs)
+        if (this != &rhs)
         {
             m_timeout = rhs.m_timeout;
             m_backlog = rhs.m_backlog;
@@ -94,9 +91,9 @@ public:
     /// Assignment operator.
     /// </summary>
     /// <returns>http_listener_config instance.</returns>
-    http_listener_config & operator=(http_listener_config &&rhs)
+    http_listener_config& operator=(http_listener_config&& rhs)
     {
-        if(this != &rhs)
+        if (this != &rhs)
         {
             m_timeout = std::move(rhs.m_timeout);
             m_backlog = std::move(rhs.m_backlog);
@@ -111,39 +108,27 @@ public:
     /// Get the timeout
     /// </summary>
     /// <returns>The timeout (in seconds).</returns>
-    utility::seconds timeout() const
-    {
-        return m_timeout;
-    }
+    utility::seconds timeout() const { return m_timeout; }
 
     /// <summary>
     /// Set the timeout
     /// </summary>
     /// <param name="timeout">The timeout (in seconds) used for each send and receive operation on the client.</param>
-    void set_timeout(utility::seconds timeout)
-    {
-        m_timeout = std::move(timeout);
-    }
+    void set_timeout(utility::seconds timeout) { m_timeout = std::move(timeout); }
 
     /// <summary>
     /// Get the listen backlog
     /// </summary>
-    /// <returns>The maximum length of the queue of pending connections, or zero for the implementation default.</returns>
-    /// <remarks>The implementation may not honour this value.</remarks>
-    int backlog() const
-    {
-        return m_backlog;
-    }
+    /// <returns>The maximum length of the queue of pending connections, or zero for the implementation
+    /// default.</returns> <remarks>The implementation may not honour this value.</remarks>
+    int backlog() const { return m_backlog; }
 
     /// <summary>
     /// Set the listen backlog
     /// </summary>
-    /// <param name="backlog">The maximum length of the queue of pending connections, or zero for the implementation default.</param>
-    /// <remarks>The implementation may not honour this value.</remarks>
-    void set_backlog(int backlog)
-    {
-        m_backlog = backlog;
-    }
+    /// <param name="backlog">The maximum length of the queue of pending connections, or zero for the implementation
+    /// default.</param> <remarks>The implementation may not honour this value.</remarks>
+    void set_backlog(int backlog) { m_backlog = backlog; }
 
 #if !defined(_WIN32) || defined(CPPREST_FORCE_HTTP_LISTENER_ASIO)
     /// <summary>
@@ -158,15 +143,15 @@ public:
     /// <summary>
     /// Set the callback of ssl context
     /// </summary>
-    /// <param name="ssl_context_callback">The function to configure a ssl context which will setup https connections.</param>
-    void set_ssl_context_callback(const std::function<void(boost::asio::ssl::context&)> &ssl_context_callback)
+    /// <param name="ssl_context_callback">The function to configure a ssl context which will setup https
+    /// connections.</param>
+    void set_ssl_context_callback(const std::function<void(boost::asio::ssl::context&)>& ssl_context_callback)
     {
         m_ssl_context_callback = ssl_context_callback;
     }
 #endif
 
 private:
-
     utility::seconds m_timeout;
     int m_backlog;
 #if !defined(_WIN32) || defined(CPPREST_FORCE_HTTP_LISTENER_ASIO)
@@ -176,19 +161,13 @@ private:
 
 namespace details
 {
-
 /// <summary>
 /// Internal class for pointer to implementation design pattern.
 /// </summary>
 class http_listener_impl
 {
 public:
-
-    http_listener_impl()
-        : m_closed(true)
-        , m_close_task(pplx::task_from_result())
-    {
-    }
+    http_listener_impl() : m_closed(true), m_close_task(pplx::task_from_result()) {}
 
     _ASYNCRTIMP http_listener_impl(http::uri address);
     _ASYNCRTIMP http_listener_impl(http::uri address, http_listener_config config);
@@ -202,16 +181,15 @@ public:
     /// <remarks>Only HTTP server implementations should call this API.</remarks>
     _ASYNCRTIMP void handle_request(http::http_request msg);
 
-    const http::uri & uri() const { return m_uri; }
+    const http::uri& uri() const { return m_uri; }
 
-    const http_listener_config & configuration() const { return m_config; }
+    const http_listener_config& configuration() const { return m_config; }
 
     // Handlers
     std::function<void(http::http_request)> m_all_requests;
     std::map<http::method, std::function<void(http::http_request)>> m_supported_methods;
 
 private:
-
     // Default implementation for TRACE and OPTIONS.
     void handle_trace(http::http_request message);
     void handle_options(http::http_request message);
@@ -235,7 +213,6 @@ private:
 class http_listener
 {
 public:
-
     /// <summary>
     /// Create a listener from a URI.
     /// </summary>
@@ -261,22 +238,24 @@ public:
     /// </summary>
     /// <remarks>The resulting listener cannot be used for anything, but is useful to initialize a variable
     /// that will later be overwritten with a real listener instance.</remarks>
-    http_listener()
-        : m_impl(utility::details::make_unique<details::http_listener_impl>())
-    {
-    }
+    http_listener() : m_impl(utility::details::make_unique<details::http_listener_impl>()) {}
 
     /// <summary>
     /// Destructor frees any held resources.
     /// </summary>
     /// <remarks>Call close() before allowing a listener to be destroyed.</remarks>
-    ~http_listener() {
-        if (m_impl) {
+    ~http_listener()
+    {
+        if (m_impl)
+        {
             // As a safe guard close the listener if not already done.
             // Users are required to call close, but this is just a safeguard.
-            try {
+            try
+            {
                 m_impl->close().wait();
-            } catch (...) {
+            }
+            catch (...)
+            {
             }
         }
     }
@@ -285,42 +264,32 @@ public:
     /// Asynchronously open the listener, i.e. start accepting requests.
     /// </summary>
     /// <returns>A task that will be completed once this listener is actually opened, accepting requests.</returns>
-    pplx::task<void> open()
-    {
-        return m_impl->open();
-    }
+    pplx::task<void> open() { return m_impl->open(); }
 
     /// <summary>
     /// Asynchronously stop accepting requests and close all connections.
     /// </summary>
-    /// <returns>A task that will be completed once this listener is actually closed, no longer accepting requests.</returns>
-    /// <remarks>
-    /// This function will stop accepting requests and wait for all outstanding handler calls
-    /// to finish before completing the task. Waiting on the task returned from close() within
-    /// a handler and blocking waiting for its result will result in a deadlock.
+    /// <returns>A task that will be completed once this listener is actually closed, no longer accepting
+    /// requests.</returns> <remarks> This function will stop accepting requests and wait for all outstanding handler
+    /// calls to finish before completing the task. Waiting on the task returned from close() within a handler and
+    /// blocking waiting for its result will result in a deadlock.
     ///
     /// Call close() before allowing a listener to be destroyed.
     /// </remarks>
-    pplx::task<void> close()
-    {
-        return m_impl->close();
-    }
+    pplx::task<void> close() { return m_impl->close(); }
 
     /// <summary>
     /// Add a general handler to support all requests.
     /// </summary>
     /// <param name="handler">Function object to be called for all requests.</param>
-    void support(const std::function<void(http_request)> &handler)
-    {
-        m_impl->m_all_requests = handler;
-    }
+    void support(const std::function<void(http_request)>& handler) { m_impl->m_all_requests = handler; }
 
     /// <summary>
     /// Add support for a specific HTTP method.
     /// </summary>
     /// <param name="method">An HTTP method.</param>
     /// <param name="handler">Function object to be called for all requests for the given HTTP method.</param>
-    void support(const http::method &method, const std::function<void(http_request)> &handler)
+    void support(const http::method& method, const std::function<void(http_request)>& handler)
     {
         m_impl->m_supported_methods[method] = handler;
     }
@@ -329,30 +298,27 @@ public:
     /// Get the URI of the listener.
     /// </summary>
     /// <returns>The URI this listener is for.</returns>
-    const http::uri & uri() const { return m_impl->uri(); }
+    const http::uri& uri() const { return m_impl->uri(); }
 
     /// <summary>
     /// Get the configuration of this listener.
     /// </summary>
     /// <returns>Configuration this listener was constructed with.</returns>
-    const http_listener_config & configuration() const { return m_impl->configuration(); }
+    const http_listener_config& configuration() const { return m_impl->configuration(); }
 
     /// <summary>
     /// Move constructor.
     /// </summary>
     /// <param name="other">http_listener instance to construct this one from.</param>
-    http_listener(http_listener &&other)
-        : m_impl(std::move(other.m_impl))
-    {
-    }
+    http_listener(http_listener&& other) : m_impl(std::move(other.m_impl)) {}
 
     /// <summary>
     /// Move assignment operator.
     /// </summary>
     /// <param name="other">http_listener to replace this one with.</param>
-    http_listener &operator=(http_listener &&other)
+    http_listener& operator=(http_listener&& other)
     {
-        if(this != &other)
+        if (this != &other)
         {
             m_impl = std::move(other.m_impl);
         }
@@ -360,15 +326,17 @@ public:
     }
 
 private:
-
     // No copying of listeners.
-    http_listener(const http_listener &other);
-    http_listener &operator=(const http_listener &other);
+    http_listener(const http_listener& other);
+    http_listener& operator=(const http_listener& other);
 
     std::unique_ptr<details::http_listener_impl> m_impl;
 };
 
-}}}}
+} // namespace listener
+} // namespace experimental
+} // namespace http
+} // namespace web
 
 #endif
 #endif
