@@ -248,6 +248,28 @@ public:
         m_msg = m_errorCode.message();
     }
 
+    /// <summary>
+    /// Creates an <c>http_exception</c> with from a error code with a category, and a string message.
+    /// </summary>
+    /// <param name="errorCode">Error code value.</param>
+    /// <param name="whatArg">Error message string.</param>
+    http_exception(std::error_code errorCode, const utility::string_t& whatArg)
+        : m_errorCode(std::move(errorCode)), m_msg(utility::conversions::to_utf8string(whatArg))
+    {
+    }
+
+#ifdef _WIN32
+    /// <summary>
+    /// Creates an <c>http_exception</c> with from a error code with a category, and a string message.
+    /// </summary>
+    /// <param name="errorCode">Error code value.</param>
+    /// <param name="whatArg">Error message string.</param>
+    http_exception(std::error_code errorCode, std::string whatArg)
+        : m_errorCode(std::move(errorCode)), m_msg(std::move(whatArg))
+    {
+    }
+#endif
+
     /// <summary>
     /// Gets a string identifying the cause of the exception.
     /// </summary>
@@ -281,6 +303,8 @@ public:
 
     virtual ~http_msg_base() {}
 
+    http::http_version http_version() const { return m_http_version; }
+
     http_headers& headers() { return m_headers; }
 
     _ASYNCRTIMP void set_body(const concurrency::streams::istream& instream, const utf8string& contentType);
@@ -419,6 +443,8 @@ public:
     /// </remarks>
     _ASYNCRTIMP size_t _get_content_length_and_set_compression();
 
+    void _set_http_version(const http::http_version& http_version) { m_http_version = http_version; }
+
 protected:
     std::unique_ptr<http::compression::compress_provider> m_compressor;
     std::unique_ptr<http::compression::decompress_provider> m_decompressor;
@@ -444,6 +470,7 @@ protected:
     /// </summary>
     concurrency::streams::ostream m_outStream;
 
+    http::http_version m_http_version;
     http_headers m_headers;
     bool m_default_outstream;
 
@@ -838,8 +865,6 @@ public:
 
     _ASYNCRTIMP void set_request_uri(const uri&);
 
-    http::http_version http_version() const { return m_http_version; }
-
     const utility::string_t& remote_address() const { return m_remote_address; }
 
     const pplx::cancellation_token& cancellation_token() const { return m_cancellationToken; }
@@ -876,8 +901,6 @@ public:
 
     void _set_base_uri(const http::uri& base_uri) { m_base_uri = base_uri; }
 
-    void _set_http_version(const http::http_version& http_version) { m_http_version = http_version; }
-
     void _set_remote_address(const utility::string_t& remote_address) { m_remote_address = remote_address; }
 
 private:
@@ -906,8 +929,6 @@ private:
 
     pplx::task_completion_event<http_response> m_response;
 
-    http::http_version m_http_version;
-
     utility::string_t m_remote_address;
 };
 
