@@ -179,7 +179,7 @@ struct BJHand
         {
             if (iter->value == CV_Ace) hasAces = true;
 
-            res.low += std::min((int)iter->value, 10);
+            res.low += (std::min)((int)iter->value, 10);
         }
         res.high = hasAces ? res.low + 10 : res.low;
         return res;
@@ -271,7 +271,7 @@ struct Player
 
     static Player FromJSON(const web::json::object& object)
     {
-        Player result(U(""));
+        Player result(utility::string_t{});
 
         auto iName = object.find(NAME);
         if (iName == object.end())
