@@ -128,83 +128,6 @@ SUITE(authentication_tests)
         }
     }
 
-// These tests are specific to our websocketpp based implementation.
-#if !defined(__cplusplus_winrt)
-
-    void sni_test_impl(websocket_client & client)
-    {
-        try
-        {
-            client.connect(U("wss://swordsoftruth.com")).wait();
-
-            // Should never be reached.
-            VERIFY_IS_TRUE(false);
-        }
-        catch (const websocket_exception& e)
-        {
-            if (is_timeout(e.what()))
-            {
-                // Since this test depends on an outside server sometimes it sporadically can fail due to timeouts
-                // especially on our build machines.
-                return;
-            }
-
-            // This test just covers establishing the TLS connection and verifying
-            // the server certificate, expect it to return an unexpected HTTP status code.
-            if (e.error_code().value() == 20)
-            {
-                return;
-            }
-            throw;
-        }
-    }
-
-    // Test specifically for server SignalR team hit interesting cases with.
-    TEST(sni_with_older_server_test)
-    {
-        websocket_client client;
-        sni_test_impl(client);
-    }
-
-    // WinRT doesn't expose option for disabling.
-    // No stable server is available to reliably test this.
-    // The configuration below relies on a timeout in the success case.
-    TEST(disable_sni, "Ignore", "Manual")
-    {
-        websocket_client_config config;
-        config.set_server_name("expired.badssl.com");
-        config.disable_sni();
-        websocket_client client(config);
-
-        try
-        {
-            client.connect(U("wss://badssl.com")).wait();
-
-            // Should never be reached.
-            VERIFY_IS_TRUE(false);
-        }
-        catch (const websocket_exception& e)
-        {
-            // Should fail for a reason different than invalid HTTP status.
-            if (e.error_code().value() != 20)
-            {
-                return;
-            }
-            throw;
-        }
-    }
-
-    // Winrt doesn't allow explicitly setting server host for SNI.
-    TEST(sni_explicit_hostname)
-    {
-        websocket_client_config config;
-        const auto& name = utf8string("swordsoftruth.com");
-        config.set_server_name(name);
-        VERIFY_ARE_EQUAL(name, config.server_name());
-        websocket_client client(config);
-        sni_test_impl(client);
-    }
-
     void handshake_error_test_impl(const ::utility::string_t& host)
     {
         websocket_client client;
@@ -231,8 +154,6 @@ SUITE(authentication_tests)
 
     TEST(cert_expired) { handshake_error_test_impl(U("wss://expired.badssl.com/")); }
 
-#endif
-
 } // SUITE(authentication_tests)
 
 } // namespace client
